########## Precautions and Limitations ##########
# 1. All the render parameters and lights should be set manually before running this script. The script will do nothing about it.
# 2. The camera should be placed in the 2nd quadrant, pointing towards the origin. Additionally, the vehicle should head along y-axis towards -ve direction initially. You can verify this by switching to Front View to see if it really shows the head of the vehicle or not.\n
# 3. The vehicle itself should be a single mesh object, join all together if there is more than one.
# 4. The vehicle object should not be translated or rotated in "Transform Properties". Object scales should be the same in all directions.
# 5. You need to "tilt" the "car" by yourself in Edit Mode if you are making tilt trains.
#################################################

bl_info = {
	"name": "Auto renderer for Locomotion (Panel Edition)",
	"author": "K.Y.Chung",
	"version": (5, 0, 1),
	"blender": (2, 5, 7),
	"api": 35853,
	"location": "View3D > Properties > Render for Locomotion Panel",
	"description": "Generate sprites for Locomotion Objects",
	"warning": "",
	"wiki_url": "",
	"tracker_url": "",
	"category": "Render"}

import bpy
from bpy.props import *
import math
from bpy import path

vehType = 0
targetObject = 0

# Sprites for Railway Car Bogies
b1 = range ( 0, 16 ) # Sprite indexes for horizontal
b2 = range ( 16, 48 ) # Sprite indexes for 11.5 degree slopes

# Sprites for Railway Cars / Narrow Gauge Railway Cars / Ships / Aircrafts
i1 = range ( 0, 64 ) # Sprite indexes for horizontal
	
# Additional sprites for Railway Cars / Narrow Gauge Railway Cars / Aircrafts
i2 = range ( 64, 68 ) # Sprite indexes for 6 degree slope 
i3 = range ( 68, 72 ) # Sprite indexes for -6 degree slopes
i4 = range ( 72, 104 ) # Sprite indexes for 11.5 degree slopes
i5 = range ( 104, 136 ) # Sprite indexes for -11.5 degree slopes

# Additional sprites for Narrow Gauge Railway Cars
i6 = range ( 136, 140 ) # Sprite indexes for 17 degree slopes
i7 = range ( 140, 144 ) # Sprite indexes for -17 degree slopes
i8 = range ( 144, 176 ) # Sprite indexes for 22.5 degree slopes
i9 = range ( 176, 208 ) # Sprite indexes for -22.5 degree slopes
	
# Sprites for Road Vehicles / Trams / Aircraft Shadows
j1 = range ( 0, 32 ) # Sprite indexes for horizontal
j2 = range ( 32, 36 ) # Sprite indexes for 6 degree slope 
j3 = range ( 36, 40 ) # Sprite indexes for -6 degree slopes
j4 = range ( 40, 44 ) # Sprite indexes for 11.5 degree slopes
j5 = range ( 44, 48 ) # Sprite indexes for -11.5 degree slopes
j6 = range ( 48, 52 ) # Sprite indexes for 17 degree slopes
j7 = range ( 52, 56 ) # Sprite indexes for -17 degree slopes
j8 = range ( 56, 60 ) # Sprite indexes for 22.5 degree slopes
j9 = range ( 60, 64 ) # Sprite indexes for -22.5 degree slopes

# Sprites for Aircraft Shadows
k1 = range ( 136, 168 )
	
#Sprites for Buildings
k2 = range ( 0, 4 )

def autoRender(n, context):
	global vehType

	# Get the sprite index, shift or multiply for some vehicle types
	if (vehType == 3):
		n = n * 2
	if (vehType == 4):
		n = ( n * 2 ) + 1
	if (vehType == 9):
		n = n * 3
	if (vehType == 10):
		n = ( n * 3 ) + 1
	if (vehType == 11):
		n = ( n * 3 ) + 2
	k = str(n)
	while (len(k) < 3): # Fill leading zeros
		k = '0' + k		

	# Render and save
	bpy.ops.render.render()
	bpy.data.images['Render Result'].save_render(path.abspath(context.scene.render.filepath) + k + '.' + str.lower(context.scene.render.file_format))

def main_c(ob, c, context):
	global vehType
	global b1, b2, i1, i2, i3, i4, i5, i6, i7, i8, i9, j1, j2, j3, j4, j5, j6, j7, j8, j9, k1, k2
	
	#Get the initial pose of the camera
	c_locationXInit = c.location.x
	c_locationYInit = c.location.y
	c_rotation_eulerZInit = c.rotation_euler.z
	c_modulus = math.hypot ( c_locationXInit, c_locationYInit )
	
	if (vehType == 13):
		for x in b1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - b1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in b2:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - b2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	if ((vehType == 1) or (vehType == 2) or (vehType == 6) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 32 * ( x - i1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
	if ((vehType == 1) or (vehType == 2) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i4[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
	if ((vehType == 1) or (vehType == 2) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i3:
			ob.rotation_euler.x = math.pi / 30
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i3[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i5[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
	if (vehType == 2):
		for x in i6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i6[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i7:
			ob.rotation_euler.x = math.pi / 180 * 17
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i7[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i8[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i9[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	if ((vehType == 3) or (vehType == 4) or (vehType == 5)):
		for x in j1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - j1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j3:
			ob.rotation_euler.x = math.pi / 30
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j3[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j4[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j5[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j6[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j7:
			ob.rotation_euler.x = math.pi / 180 * 17
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j7[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j8[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j9[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
	
	if (vehType == 12):
		for x in k1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - k1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		
	if (vehType == 8):
		for x in k2:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - k2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	# Reset object orientations
	ob.rotation_euler.x = 0

def main_o(ob, context):
	global vehType
	global b1, b2, i1, i2, i3, i4, i5, i6, i7, i8, i9, j1, j2, j3, j4, j5, j6, j7, j8, j9, k1, k2

	if (vehType == 13):
		for x in b1:
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - b1[0] ) )
			autoRender(x, context)
		for x in b2:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - b2[0] ) )
			autoRender(x, context)

	if ((vehType == 1) or (vehType == 2) or (vehType == 6) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i1:
			ob.rotation_euler.z = - ( math.pi / 32 * ( x - i1[0] ) )
			autoRender(x, context)

	if ((vehType == 1) or (vehType == 2) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i2[0] ) )
			autoRender(x, context)
		for x in i4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i4[0] ) )
			autoRender(x, context)

	if ((vehType == 1) or (vehType == 2) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i3:
			ob.rotation_euler.x = math.pi / 30
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i3[0] ) )
			autoRender(x, context)
		for x in i5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i5[0] ) )
			autoRender(x, context)

	if (vehType == 2):
		for x in i6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i6[0] ) )
			autoRender(x, context)
		for x in i7:
			ob.rotation_euler.x = math.pi / 180 * 17
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i7[0] ) )
			autoRender(x, context)
		for x in i8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i8[0] ) )
			autoRender(x, context)
		for x in i9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i9[0] ) )
			autoRender(x, context)

	if ((vehType == 3) or (vehType == 4) or (vehType == 5)):
		for x in j1:
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - j1[0] ) )
			autoRender(x, context)
		for x in j2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j2[0] ) )
			autoRender(x, context)
		for x in j3:
			ob.rotation_euler.x = math.pi / 30
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j3[0] ) )
			autoRender(x, context)
		for x in j4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j4[0] ) )
			autoRender(x, context)
		for x in j5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j5[0] ) )
			autoRender(x, context)
		for x in j6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j6[0] ) )
			autoRender(x, context)
		for x in j7:
			ob.rotation_euler.x = math.pi / 180 * 17
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j7[0] ) )
			autoRender(x, context)
		for x in j8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j8[0] ) )
			autoRender(x, context)
		for x in j9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j9[0] ) )
			autoRender(x, context)

	if (vehType == 12):
		for x in k1:
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - k1[0] ) )
			autoRender(x, context)
		
	if (vehType == 8):
		for x in k2:
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - k2[0] ) )
			autoRender(x, context)

	# Reset object orientations
	ob.rotation_euler.x = 0
	ob.rotation_euler.z = 0



########## UI Related ##########

vehType_ui = '0'
targetObject_ui = '0'

class dialogOperator(bpy.types.Operator):
	bl_idname = "bpt.locorenderer_exe"
	bl_label = "Start"

	def execute(self, context):
		global vehType, targetObject
		vehType = int(context.scene.vehType_ui)
		targetObject = int(context.scene.targetObject_ui)
		if ((vehType > 0) and (targetObject > 0)):
			ob = context.active_object # Gets the current active object (If Any)
			c = context.scene.camera # Gets the active camera
			if ((ob == None) or (str(ob.type) != 'MESH')): # Checks if the active object is a mesh
				self.report({'WARNING'}, 'Error: Select a mesh object first')
			else:
				if (targetObject == 1):
					main_o(ob, context)
				elif (targetObject == 2):
					main_c(ob, c, context)
		return {'FINISHED'}


class locoRenderer(bpy.types.Panel):
	bl_label = "Render for Locomotion"
	bl_space_type = "PROPERTIES"
	bl_region_type = "WINDOW"
	bl_context = "render"

	def draw(self, context):
		layout = self.layout  
		scn = context.scene
		row = layout.row()
		col = row.column()
		col.prop( scn, "vehType_ui" )
		row = layout.row()
		col = row.column()
		col.prop( scn, "targetObject_ui" )
		row = layout.row()
		row.operator( "bpt.locorenderer_exe" )
		
########## End UI Related ##########




def register():
	bpy.utils.register_class(dialogOperator)
	bpy.utils.register_class(locoRenderer)
	bpy.types.Scene.vehType_ui = EnumProperty(name="Vehicle Type",
		items = [('0', '------ Choose ------', '------ Choose ------'),
				 ('1', 'Railway Cars', 'Railway Cars'),
				 ('9', 'Railway Cars (Tilt Trains)', 'Railway Cars (Tilt Trains)'),
				 ('10', 'Railway Cars (Tilt Trains banking left)', 'Railway Cars (Tilt Trains banking left)'),
				 ('11', 'Railway Cars (Tilt Trains banking right)', 'Railway Cars (Tilt Trains banking right)'),
				 ('13', 'Railway Car Bogies', 'Railway Car Bogies'),
				 ('2', 'Narrow Gauge Railway Cars', 'Narrow Gauge Railway Cars'),
				 ('3', 'Road Vehicles', 'Road Vehicles'),
				 ('4', 'Braking Lights of Road Vehicles', 'Braking Lights of Road Vehicles'),
				 ('5', 'Trams', 'Trams'),
				 ('6', 'Ships', 'Ships'),
				 ('7', 'Aircrafts', 'Aircrafts'),
				 ('12', 'Aircraft Shadows', 'Aircraft Shadows'),
				 ('8', 'Buildings', 'Buildings')])
	bpy.types.Scene.targetObject_ui = EnumProperty(name="Object to rotate/orbit",
		items = [('0', '------ Choose ------', '------ Choose ------'),
				 ('1', 'Mesh', 'Mesh'),
				 ('2', 'Camera', 'Camera')])

def unregister():
	bpy.utils.unregister_class(dialogOperator)
	bpy.utils.unregister_class(locoRenderer)
	del bpy.types.Scene.vehType_ui
	del bpy.types.Scene.targetObject_ui

if __name__ == "__main__":
	register()