########## Precautions and Limitations ##########
# 1. All the render parameters and lights should be set manually before running this script. The script will do nothing about it.
# 2. The camera should be placed in the 2nd quadrant, pointing towards the origin. Additionally, the vehicle should head along y-axis towards -ve direction initially. You can verify this by switching to Front View to see if it really shows the head of the vehicle or not.\n
# 3. The vehicle itself should be a single mesh object, join all together if there is more than one.
# 4. The vehicle object should not be translated or rotated in "Transform Properties". Object scales should be the same in all directions.
# 5. You need to "tilt" the "car" by yourself in Edit Mode if you are making tilt trains.
#################################################

bl_info = {
	"name": "Auto renderer for Locomotion (Menu Edition)",
	"author": "K.Y.Chung",
	"version": (5, 0, 1),
	"blender": (2, 5, 7),
	"api": 35853,
	"location": "View3D > Render > Render for Locomotion",
	"description": "Generate sprites for Locomotion Objects",
	"warning": "",
	"wiki_url": "",
	"tracker_url": "",
	"category": "Render"}

import bpy
from bpy.props import *
import math
from bpy import path

vehType = 0
targetObject = 0

# Sprites for Railway Car Bogies
b1 = range ( 0, 16 ) # Sprite indexes for horizontal
b2 = range ( 16, 48 ) # Sprite indexes for 11.5 degree slopes

# Sprites for Railway Cars / Narrow Gauge Railway Cars / Ships / Aircrafts
i1 = range ( 0, 64 ) # Sprite indexes for horizontal
	
# Additional sprites for Railway Cars / Narrow Gauge Railway Cars / Aircrafts
i2 = range ( 64, 68 ) # Sprite indexes for 6 degree slope 
i3 = range ( 68, 72 ) # Sprite indexes for -6 degree slopes
i4 = range ( 72, 104 ) # Sprite indexes for 11.5 degree slopes
i5 = range ( 104, 136 ) # Sprite indexes for -11.5 degree slopes

# Additional sprites for Narrow Gauge Railway Cars
i6 = range ( 136, 140 ) # Sprite indexes for 17 degree slopes
i7 = range ( 140, 144 ) # Sprite indexes for -17 degree slopes
i8 = range ( 144, 176 ) # Sprite indexes for 22.5 degree slopes
i9 = range ( 176, 208 ) # Sprite indexes for -22.5 degree slopes
	
# Sprites for Road Vehicles / Trams / Aircraft Shadows
j1 = range ( 0, 32 ) # Sprite indexes for horizontal
j2 = range ( 32, 36 ) # Sprite indexes for 6 degree slope 
j3 = range ( 36, 40 ) # Sprite indexes for -6 degree slopes
j4 = range ( 40, 44 ) # Sprite indexes for 11.5 degree slopes
j5 = range ( 44, 48 ) # Sprite indexes for -11.5 degree slopes
j6 = range ( 48, 52 ) # Sprite indexes for 17 degree slopes
j7 = range ( 52, 56 ) # Sprite indexes for -17 degree slopes
j8 = range ( 56, 60 ) # Sprite indexes for 22.5 degree slopes
j9 = range ( 60, 64 ) # Sprite indexes for -22.5 degree slopes

# Sprites for Aircraft Shadows
k1 = range ( 136, 168 )
	
#Sprites for Buildings
k2 = range ( 0, 4 )

def autoRender(n, context):
	global vehType

	# Get the sprite index, shift or multiply for some vehicle types
	if (vehType == 3):
		n = n * 2
	if (vehType == 4):
		n = ( n * 2 ) + 1
	if (vehType == 9):
		n = n * 3
	if (vehType == 10):
		n = ( n * 3 ) + 1
	if (vehType == 11):
		n = ( n * 3 ) + 2
	k = str(n)
	while (len(k) < 3): # Fill leading zeros
		k = '0' + k

	# Render and save
	bpy.ops.render.render()
	bpy.data.images['Render Result'].save_render(path.abspath(context.scene.render.filepath) + k + '.' + str.lower(context.scene.render.file_format))

def main_c(ob, c, context):
	global vehType
	global b1, b2, i1, i2, i3, i4, i5, i6, i7, i8, i9, j1, j2, j3, j4, j5, j6, j7, j8, j9, k1, k2

	#Get the initial pose of the camera
	c_locationXInit = c.location.x
	c_locationYInit = c.location.y
	c_rotation_eulerZInit = c.rotation_euler.z
	c_modulus = math.hypot ( c_locationXInit, c_locationYInit )

	if (vehType == 13):
		for x in b1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - b1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in b2:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - b2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	if ((vehType == 1) or (vehType == 2) or (vehType == 6) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 32 * ( x - i1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
	if ((vehType == 1) or (vehType == 2) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i4[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
	if ((vehType == 1) or (vehType == 2) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i3:
			ob.rotation_euler.x = math.pi / 30
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i3[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i5[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
	if (vehType == 2):
		for x in i6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i6[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i7:
			ob.rotation_euler.x = math.pi / 180 * 17
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - i7[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i8[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in i9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - i9[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	if ((vehType == 3) or (vehType == 4) or (vehType == 5)):
		for x in j1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - j1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j3:
			ob.rotation_euler.x = math.pi / 30
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j3[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j4[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j5[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j6[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j7:
			ob.rotation_euler.x = math.pi / 180 * 17
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j7[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j8[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit
		for x in j9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - j9[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	if (vehType == 12):
		for x in k1:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 16 * ( x - k1[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	if (vehType == 8):
		for x in k2:
			c.rotation_euler.z = c_rotation_eulerZInit + ( math.pi / 2 * ( x - k2[0] ) )
			c.location.x = c_modulus * math.cos ( c.rotation_euler.z - ( math.pi / 2 ) )
			c.location.y = c_modulus * math.sin ( c.rotation_euler.z - ( math.pi / 2 ) )
			autoRender(x, context)
		#Reset camera pose
		c.location.x = c_locationXInit
		c.location.y = c_locationYInit
		c.rotation_euler.z = c_rotation_eulerZInit

	# Reset object orientations
	ob.rotation_euler.x = 0

def main_o(ob, context):
	global vehType
	global b1, b2, i1, i2, i3, i4, i5, i6, i7, i8, i9, j1, j2, j3, j4, j5, j6, j7, j8, j9, k1, k2

	if (vehType == 13):
		for x in b1:
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - b1[0] ) )
			autoRender(x, context)
		for x in b2:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - b2[0] ) )
			autoRender(x, context)

	if ((vehType == 1) or (vehType == 2) or (vehType == 6) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i1:
			ob.rotation_euler.z = - ( math.pi / 32 * ( x - i1[0] ) )
			autoRender(x, context)

	if ((vehType == 1) or (vehType == 2) or (vehType == 7) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i2[0] ) )
			autoRender(x, context)
		for x in i4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i4[0] ) )
			autoRender(x, context)

	if ((vehType == 1) or (vehType == 2) or (vehType == 9) or (vehType == 10) or (vehType == 11)):
		for x in i3:
			ob.rotation_euler.x = math.pi / 30
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i3[0] ) )
			autoRender(x, context)
		for x in i5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i5[0] ) )
			autoRender(x, context)

	if (vehType == 2):
		for x in i6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i6[0] ) )
			autoRender(x, context)
		for x in i7:
			ob.rotation_euler.x = math.pi / 180 * 17
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - i7[0] ) )
			autoRender(x, context)
		for x in i8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i8[0] ) )
			autoRender(x, context)
		for x in i9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - i9[0] ) )
			autoRender(x, context)

	if ((vehType == 3) or (vehType == 4) or (vehType == 5)):
		for x in j1:
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - j1[0] ) )
			autoRender(x, context)
		for x in j2:
			ob.rotation_euler.x = - ( math.pi / 30 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j2[0] ) )
			autoRender(x, context)
		for x in j3:
			ob.rotation_euler.x = math.pi / 30
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j3[0] ) )
			autoRender(x, context)
		for x in j4:
			ob.rotation_euler.x = - ( math.pi / 180 * 11.5 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j4[0] ) )
			autoRender(x, context)
		for x in j5:
			ob.rotation_euler.x = math.pi / 180 * 11.5
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j5[0] ) )
			autoRender(x, context)
		for x in j6:
			ob.rotation_euler.x = - ( math.pi / 180 * 17 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j6[0] ) )
			autoRender(x, context)
		for x in j7:
			ob.rotation_euler.x = math.pi / 180 * 17
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j7[0] ) )
			autoRender(x, context)
		for x in j8:
			ob.rotation_euler.x = - ( math.pi / 180 * 22.5 )
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j8[0] ) )
			autoRender(x, context)
		for x in j9:
			ob.rotation_euler.x = math.pi / 180 * 22.5
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - j9[0] ) )
			autoRender(x, context)

	if (vehType == 12):
		for x in k1:
			ob.rotation_euler.z = - ( math.pi / 16 * ( x - k1[0] ) )
			autoRender(x, context)

	if (vehType == 8):
		for x in k2:
			ob.rotation_euler.z = - ( math.pi / 2 * ( x - k2[0] ) )
			autoRender(x, context)

	# Reset object orientations
	ob.rotation_euler.x = 0
	ob.rotation_euler.z = 0



########## UI Related ##########

def locoRenderer_exe(self, context):
	global targetObject
	ob = context.active_object # Gets the current active object (If Any)
	c = context.scene.camera # Gets the active camera
	if ((ob == None) or (str(ob.type) != 'MESH')): # Checks if the active object is a mesh
		self.report({'WARNING'}, 'Error: Select a mesh object first')
	else:
		if (targetObject == 1):
			main_o(ob, context)
		elif (targetObject == 2):
			main_c(ob, c, context)
	return {'FINISHED'}

class locoRenderer(bpy.types.Menu):
	bl_idname = "locoRenderer"
	bl_label = "Render for Locomotion"
    
	def draw(self, context):
		layout = self.layout  
		layout.operator_context = 'INVOKE_REGION_WIN'
		layout.menu(locoRenderer_o.bl_idname)
		layout.menu(locoRenderer_c.bl_idname)
		
class locoRenderer_o(bpy.types.Menu):
	bl_idname = "locoRenderer_o"
	bl_label = "by Rotating Mesh Object"
    
	def draw(self, context):
		global vehType, targetObject
		targetObject = 1
		layout = self.layout  
		layout.operator_context = 'INVOKE_REGION_WIN'
		layout.operator(locoRenderer_subMenu1.bl_idname)
		layout.operator(locoRenderer_subMenu2.bl_idname)
		layout.operator(locoRenderer_subMenu3.bl_idname)
		layout.operator(locoRenderer_subMenu4.bl_idname)
		layout.operator(locoRenderer_subMenu5.bl_idname)
		layout.operator(locoRenderer_subMenu6.bl_idname)
		layout.operator(locoRenderer_subMenu7.bl_idname)
		layout.operator(locoRenderer_subMenu8.bl_idname)
		layout.operator(locoRenderer_subMenu9.bl_idname)
		layout.operator(locoRenderer_subMenu10.bl_idname)
		layout.operator(locoRenderer_subMenu11.bl_idname)
		layout.operator(locoRenderer_subMenu12.bl_idname)
		layout.operator(locoRenderer_subMenu13.bl_idname)
		
class locoRenderer_c(bpy.types.Menu):
	bl_idname = "locoRenderer_c"
	bl_label = "by Orbiting Camera"
    
	def draw(self, context):
		global vehType, targetObject
		targetObject = 2
		layout = self.layout  
		layout.operator_context = 'INVOKE_REGION_WIN'
		layout.operator(locoRenderer_subMenu1.bl_idname)
		layout.operator(locoRenderer_subMenu2.bl_idname)
		layout.operator(locoRenderer_subMenu3.bl_idname)
		layout.operator(locoRenderer_subMenu4.bl_idname)
		layout.operator(locoRenderer_subMenu5.bl_idname)
		layout.operator(locoRenderer_subMenu6.bl_idname)
		layout.operator(locoRenderer_subMenu7.bl_idname)
		layout.operator(locoRenderer_subMenu8.bl_idname)
		layout.operator(locoRenderer_subMenu9.bl_idname)
		layout.operator(locoRenderer_subMenu10.bl_idname)
		layout.operator(locoRenderer_subMenu11.bl_idname)
		layout.operator(locoRenderer_subMenu12.bl_idname)
		layout.operator(locoRenderer_subMenu13.bl_idname)

class locoRenderer_subMenu1(bpy.types.Operator):
	bl_idname = "object.dialog_operator01"
	bl_label = "Railway Cars"

	def execute(self, context):
		global vehType
		vehType = 1
		locoRenderer_exe(self, context)

class locoRenderer_subMenu2(bpy.types.Operator):
	bl_idname = "object.dialog_operator02"
	bl_label = "Narrow Gauge Railway Cars"

	def execute(self, context):
		global vehType
		vehType = 2
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu3(bpy.types.Operator):
	bl_idname = "object.dialog_operator03"
	bl_label = "Road Vehicles"

	def execute(self, context):
		global vehType
		vehType = 3
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu4(bpy.types.Operator):
	bl_idname = "object.dialog_operator04"
	bl_label = "Braking Lights of Road Vehicles"

	def execute(self, context):
		global vehType
		vehType = 4
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu5(bpy.types.Operator):
	bl_idname = "object.dialog_operator05"
	bl_label = "Trams"

	def execute(self, context):
		global vehType
		vehType = 5
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu6(bpy.types.Operator):
	bl_idname = "object.dialog_operator06"
	bl_label = "Ships"

	def execute(self, context):
		global vehType
		vehType = 6
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu7(bpy.types.Operator):
	bl_idname = "object.dialog_operator07"
	bl_label = "Aircrafts"

	def execute(self, context):
		global vehType
		vehType = 7
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu8(bpy.types.Operator):
	bl_idname = "object.dialog_operator08"
	bl_label = "Buildings"

	def execute(self, context):
		global vehType
		vehType = 8
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu9(bpy.types.Operator):
	bl_idname = "object.dialog_operator09"
	bl_label = "Railway Cars (Tilt Trains)"

	def execute(self, context):
		global vehType
		vehType = 9
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu10(bpy.types.Operator):
	bl_idname = "object.dialog_operator10"
	bl_label = "Railway Cars (Tilt Trains banking left)"

	def execute(self, context):
		global vehType
		vehType = 10
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu11(bpy.types.Operator):
	bl_idname = "object.dialog_operator11"
	bl_label = "Railway Cars (Tilt Trains banking right)"

	def execute(self, context):
		global vehType
		vehType = 11
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu12(bpy.types.Operator):
	bl_idname = "object.dialog_operator12"
	bl_label = "Aircraft Shadows"

	def execute(self, context):
		global vehType
		vehType = 12
		locoRenderer_exe(self, context)
		
class locoRenderer_subMenu13(bpy.types.Operator):
	bl_idname = "object.dialog_operator13"
	bl_label = "Railway Car Bogies"

	def execute(self, context):
		global vehType
		vehType = 13
		locoRenderer_exe(self, context)

def menu_func(self, context):
	self.layout.menu(locoRenderer.bl_idname)

########## End UI Related ##########



def register():
	bpy.utils.register_module(__name__)
	bpy.types.INFO_MT_render.append(menu_func)

def unregister():
	bpy.utils.unregister_module(__name__)
	bpy.types.INFO_MT_render.remove(menu_func)

if __name__ == "__main__":
	register()